@@ -32,7 +32,6 @@ import org.eclipse.linuxtools.internal.docker.ui.testutils.swt.DockerImageHierar
 import org.eclipse.linuxtools.internal.docker.ui.testutils.swt.MenuAssertion;
 import org.eclipse.linuxtools.internal.docker.ui.testutils.swt.SWTUtils;
 import org.eclipse.linuxtools.internal.docker.ui.testutils.swt.TabDescriptorAssertions;
-import org.eclipse.linuxtools.internal.docker.ui.testutils.swt.TestLoggerRule;
 import org.eclipse.swtbot.eclipse.finder.SWTWorkbenchBot;
 import org.eclipse.swtbot.eclipse.finder.widgets.SWTBotView;
 import org.eclipse.swtbot.swt.finder.exceptions.WidgetNotFoundException;
@@ -64,9 +63,6 @@ public class DockerImageHierarchyViewSWTBotTest {
 	public static CloseWelcomePageRule closeWelcomePage = new CloseWelcomePageRule(
 			CloseWelcomePageRule.DOCKER_PERSPECTIVE_ID);
 
-	@Rule
-	public TestLoggerRule watcher = new TestLoggerRule();
-
 	@Rule
 	public ClearConnectionManagerRule clearConnectionManager = new ClearConnectionManagerRule();
 	private DockerConnection connection;
@@ -74,7 +70,7 @@ public class DockerImageHierarchyViewSWTBotTest {
 	@Before
 	public void setupViews() {
 		this.bot = new SWTWorkbenchBot();
-		SWTUtils.asyncExec(() -> {
+		bot.getDisplay().asyncExec(() -> {
 			try {
 				PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage()
 						.showView(DockerExplorerView.VIEW_ID);
@@ -155,7 +151,7 @@ public class DockerImageHierarchyViewSWTBotTest {
 		final SWTBotView dockerImageHierarchyViewBot = bot.viewById(DockerImageHierarchyView.VIEW_ID);
 		final DockerImageHierarchyView dockerImageHierarchyView = (DockerImageHierarchyView) (dockerImageHierarchyViewBot
 				.getViewReference().getView(true));
-		SWTUtils.asyncExec(() -> dockerImageHierarchyView.getCommonViewer().expandAll());
+		bot.getDisplay().asyncExec(() -> dockerImageHierarchyView.getCommonViewer().expandAll());
 		// when a second call to expand the container is done (because the first
 		// expandAll stopped with a "Loading..." job that retrieved the
 		// containers)
