@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2011-2015 STMicroelectronics and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * Copyright (c) 2011, 2018 STMicroelectronics and others.
+ *
+ * This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License 2.0
+ * which is available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Xavier Raynaud <xavier.raynaud@st.com> - initial API and implementation
@@ -11,6 +13,8 @@
  *******************************************************************************/
 package org.eclipse.linuxtools.internal.gcov.test;
 
+import org.junit.jupiter.api.Test;
+
 public class GcovTestCLibrary extends GcovTest {
 
     @Override
@@ -33,6 +37,7 @@ public class GcovTestCLibrary extends GcovTest {
         return false;
     }
 
+    @Test
     @Override
     public void testGcovSummaryByLaunch() {
     }
