@@ -17,8 +17,6 @@ import static org.eclipse.linuxtools.internal.gprof.test.STJunitUtils.OUTPUT_FIL
 
 import java.io.File;
 import java.io.IOException;
-import java.io.InputStream;
-import java.io.InputStreamReader;
 import java.io.LineNumberReader;
 import java.util.ArrayList;
 import java.util.List;
@@ -53,9 +51,8 @@ public class GprofTest {
         boolean addr2line2_16 = false;
         try {
             Process p = Runtime.getRuntime().exec("addr2line --version");
-            InputStream is = p.getInputStream();
-            LineNumberReader reader = new LineNumberReader(
-                    new InputStreamReader(is));
+			LineNumberReader reader = new LineNumberReader(
+					p.inputReader());
             String line;
             while ((line = reader.readLine()) != null) {
                 if (line.contains("addr2line 2.16.")) {
